# RefundTransactionType

The transaction type of the refund. 

## Enum

* `CHARGEBACK` (value: `'Chargeback'`)

* `PAYMENTREVERSAL` (value: `'PaymentReversal'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


